@@ -35,7 +35,6 @@
 require 'rbconfig'
 require 'find'
 require 'fileutils'
-require 'ftools' # apparently on some system ftools doesn't get loaded
 require 'optparse'
 require 'ostruct'
 
@@ -91,9 +90,9 @@ def do_libs(libs, strip = 'lib/')
     libs.each do |lf|
         olf = File.join(InstallOptions.site_dir, lf.gsub(/#{strip}/, ''))
         op = File.dirname(olf)
-        File.makedirs(op, true)
-        File.chmod(0755, op)
-        File.install(lf, olf, 0644, true)
+        FileUtils.makedirs(op, {:mode => 0755, :verbose => true})
+        FileUtils.chmod(0755, op)
+        FileUtils.install(lf, olf, {:mode => 0644, :verbose => true})
     end
 end
 
@@ -101,9 +100,9 @@ def do_man(man, strip = 'man/')
     man.each do |mf|
         omf = File.join(InstallOptions.man_dir, mf.gsub(/#{strip}/, ''))
         om = File.dirname(omf)
-        File.makedirs(om, true)
-        File.chmod(0644, om)
-        File.install(mf, omf, 0644, true)
+        FileUtils.makedirs(om, {:mode => 0755, :verbose => true})
+        FileUtils.chmod(0755, om)
+        FileUtils.install(mf, omf, {:mode => 0644, :verbose => true})
         gzip = %x{which gzip}
         gzip.chomp!
         %x{#{gzip} -f #{omf}}
@@ -200,7 +199,7 @@ def prepare_installation
         opts.parse!
     end
 
-    tmpdirs = [".", ENV['TMP'], ENV['TEMP'], "/tmp", "/var/tmp"]
+    tmpdirs = [ENV['TMP'], ENV['TEMP'], "/tmp", "/var/tmp", "."]
 
     version = [Config::CONFIG["MAJOR"], Config::CONFIG["MINOR"]].join(".")
     libdir = File.join(Config::CONFIG["libdir"], "ruby", version)
@@ -317,12 +316,6 @@ def build_man(bins)
         # Locate rst2man
         rst2man = %x{which rst2man.py}
         rst2man.chomp!
-        # Create puppet.conf.8 man page
-        %x{bin/puppetdoc --reference configuration > ./puppet.conf.rst}
-        %x{#{rst2man} ./puppet.conf.rst ./man/man8/puppet.conf.8}
-        File.unlink("./puppet.conf.rst")
-
-        # Create binary man pages
         bins.each do |bin|
             b = bin.gsub( "bin/", "")
             %x{#{bin} --help > ./#{b}.rst}
